@@ -9,10 +9,6 @@ import json
 import base64
 import logging
 
-try:
-    import cStringIO as StringIO
-except ImportError:
-    import StringIO
 try:
     from collections import OrderedDotMap
 except ImportError:
@@ -168,7 +164,7 @@ class AppService(ApiRequest):
             "ip": "127.0.0.1",
             "system_user": "web",
             "login_type": "ST",
-            "was_failed": False,
+            "is_failed": 0,
             "date_start": 1484206685,
         }
         service.send_proxy_log(data)
@@ -298,13 +294,13 @@ class AppService(ApiRequest):
             "asset": "name",
             "system_user": "web",
             "login_type": "ST",
-            "was_failed": False,
+            "was_failed": 0,
             "date_start": timestamp,
         }
         """
         assert isinstance(data.get('date_start'), (int, float))
         data['date_start'] = timestamp_to_datetime_str(data['date_start'])
-        data['was_failed'] = 1 if data.get('was_failed') else 0
+        data['is_failed'] = 1 if data.get('is_failed') else 0
 
         r, content = self.post('send-proxy-log', data=data, use_auth=True)
         if r.status_code != 201:
@@ -324,7 +320,7 @@ class AppService(ApiRequest):
         """
         assert isinstance(data.get('date_finished'), (int, float))
         data['date_finished'] = timestamp_to_datetime_str(data['date_finished'])
-        data['was_failed'] = 1 if data.get('was_failed') else 0
+        data['is_failed'] = 1 if data.get('is_failed') else 0
         data['is_finished'] = 1
         proxy_log_id = data.get('proxy_log_id') or 0
         r, content = self.patch('finish-proxy-log', pk=proxy_log_id, data=data)
@@ -352,9 +348,9 @@ class AppService(ApiRequest):
         if isinstance(data, dict):
             data = [data]
         for d in data:
-            if d.get('output') and isinstance(d['output'], unicode):
+            if d.get('output') and not isinstance(d['output'], bytes):
                 d['output'] = d['output'].encode('utf-8')
-            d['output'] = base64.b64encode(d['output'])
+            d['output'] = base64.b64encode(d['output']).decode("utf-8")
         result, content = self.post('send-command-log', data=data)
         if result.status_code != 201:
             logging.warning('Send command log failed: %s' % content)
@@ -374,7 +370,7 @@ class AppService(ApiRequest):
         if isinstance(data, dict):
             data = [data]
         for d in data:
-            if d.get('output') and isinstance(d['output'], unicode):
+            if d.get('output') and isinstance(d['output'], str):
                 d['output'] = d['output'].encode('utf-8')
             d['output'] = base64.b64encode(d['output'])
         result, content = self.post('send-record-log', data=data)
@@ -458,7 +454,7 @@ class UserService(ApiRequest):
     @cached(TTLCache(maxsize=100, ttl=60))
     def is_authenticated(self):
         """根据签名判断用户是否认证"""
-        r, content = self.post('my-profile', use_auth=True)
+        r, content = self.get('my-profile', use_auth=True)
         if r.status_code == 200:
             self.user = content
             return self.user
@@ -522,6 +518,11 @@ class UserService(ApiRequest):
             assets = content
         else:
             assets = []
+
+        for asset in assets:
+            asset['system_users'] = \
+                [system_user for system_user in asset.get('system_users_granted')]
+
         assets = sort_assets(assets)
         return to_dotmap([asset for asset in assets])
 
